==> open-xchange-authentication-ucs_7.8.4.orig.tar.bz2: open-xchange-authentication-ucs-7.8.4/com.openexchange.authentication.ucs/src/com/openexchange/authentication/ucs/osgi/UCSAuthActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */



package com.openexchange.authentication.ucs.osgi;

import java.util.Properties;
import org.osgi.framework.ServiceRegistration;
import com.openexchange.authentication.AuthenticationService;
import com.openexchange.authentication.ucs.impl.UCSAuthentication;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.Reloadable;
import com.openexchange.osgi.DeferredActivator;

public class UCSAuthActivator extends DeferredActivator {

    private static transient final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(UCSAuthActivator.class);

    /**
     * Reference to the service registration.
     */
    private ServiceRegistration<AuthenticationService> registration;
    private ServiceRegistration<Reloadable> reloadable;

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigurationService.class };
    }

    @Override
    protected void handleUnavailability(Class<?> clazz) {
        // TODO Auto-generated method stub
        
    }

    @Override
    protected void handleAvailability(Class<?> clazz) {
        // TODO Auto-generated method stub
        
    }

    @Override
    protected void startBundle() throws Exception {
        LOG.info("starting bundle: com.openexchange.authentication.ucs");
        final ConfigurationService config = getService(ConfigurationService.class);
        final Properties props = config.getFile(UCSAuthentication.CONFIGFILE);

        if (null == registration) {
            final UCSAuthentication impl = new UCSAuthentication(props);
            registration = context.registerService(AuthenticationService.class, impl, null);
            reloadable = context.registerService(Reloadable.class, impl, null);
        } else {
            LOG.error("Duplicate startup of deferred activator.");
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        LOG.info("Stopping bundle: com.openexchange.authentication.ucs");
        if (null != registration) {
            registration.unregister();
            registration = null;
        }
        if (null != reloadable) {
            reloadable.unregister();
            reloadable = null;
        }
    }
}

==> open-xchange-authentication-ucs_7.10.1.orig.tar.bz2: open-xchange-authentication-ucs-7.10.1/com.openexchange.authentication.ucs/src/com/openexchange/authentication/ucs/osgi/UCSAuthActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */



package com.openexchange.authentication.ucs.osgi;

import com.openexchange.authentication.AuthenticationService;
import com.openexchange.authentication.ucs.common.UCSLookup;
import com.openexchange.authentication.ucs.impl.UCSAuthentication;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link UCSAuthActivator} - The activator for the <code>"com.openexchange.authentication.ucs"</code> bundle.
 */
public class UCSAuthActivator extends HousekeepingActivator {

    private static transient final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(UCSAuthActivator.class);

    /**
     * Initializes a new {@link UCSAuthActivator}.
     */
    public UCSAuthActivator() {
        super();
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { UCSLookup.class };
    }

    @Override
    protected synchronized void startBundle() throws Exception {
        LOG.info("starting bundle: com.openexchange.authentication.ucs");

        UCSAuthentication impl = new UCSAuthentication(getServiceSafe(UCSLookup.class));
        registerService(AuthenticationService.class, impl);
    }

    @Override
    protected synchronized void stopBundle() throws Exception {
        LOG.info("Stopping bundle: com.openexchange.authentication.ucs");
        super.stopBundle();
    }
}
